#!/bin/bash
#
# artifactory-docker pipe
#
# Required globals:
#   ARTIFACTORY_URL
#   ARTIFACTORY_USER
#   ARTIFACTORY_PASSWORD
#   DOCKER_IMAGE_TAG
#   DOCKER_TARGET_REPO
#
# Optional globals:
#   EXTRA_ARGS
#   JFROG_CLI_TEMP_DIR
#   JFROG_CLI_HOME_DIR
#   COLLECT_ENV
#   COLLECT_BUILD_INFO
#   BUILD_NAME
#

source "$(dirname "$0")/common.sh"

## Enable debug mode.
DEBUG_ARGS=
enable_debug() {
  if [[ "${DEBUG}" == "true" ]]; then
    info "Enabling debug mode."
    set -x
    DEBUG_ARGS="--verbose"
    export JFROG_CLI_LOG_LEVEL="DEBUG"
  fi
}

info "Starting pipe execution..."

# required parameters
ARTIFACTORY_URL=${ARTIFACTORY_URL:?'ARTIFACTORY_URL variable missing.'}
ARTIFACTORY_USER=${ARTIFACTORY_USER:?'ARTIFACTORY_USER variable missing.'}
ARTIFACTORY_PASSWORD=${ARTIFACTORY_PASSWORD:?'ARTIFACTORY_PASSWORD variable missing.'}
DOCKER_IMAGE_TAG=${DOCKER_IMAGE_TAG:?'DOCKER_IMAGE_TAG variable missing.'}
DOCKER_TARGET_REPO=${DOCKER_TARGET_REPO:?'DOCKER_TARGET_REPO variable missing.'}

# optional parameters
BUILD_NAME=${BUILD_NAME:=$BITBUCKET_REPO_OWNER-$BITBUCKET_REPO_SLUG-$BITBUCKET_BRANCH}
JFROG_CLI_TEMP_DIR=${JFROG_CLI_TEMP_DIR:="."}
JFROG_CLI_HOME_DIR=${JFROG_CLI_HOME_DIR:="."}
COLLECT_ENV=${COLLECT_ENV:="true"}
COLLECT_BUILD_INFO=${COLLECT_BUILD_INFO:="true"}
EXTRA_ARGS=${EXTRA_ARGS:=""}
DEBUG=${DEBUG:="false"}

# Set the environment variable
export JFROG_CLI_TEMP_DIR=$JFROG_CLI_TEMP_DIR
export JFROG_CLI_HOME_DIR=$JFROG_CLI_HOME_DIR
export BUILD_URL="https://bitbucket.org/${BITBUCKET_REPO_OWNER}/${BITBUCKET_REPO_SLUG}/addon/pipelines/home#!/results/${BITBUCKET_BUILD_NUMBER}"

debug "build name is ${BUILD_NAME}"
debug "build number is ${BITBUCKET_BUILD_NUMBER}"

# Configure Artifactory instance with JFrog CLI
run jfrog rt config --url=$ARTIFACTORY_URL --user=$ARTIFACTORY_USER --password=$ARTIFACTORY_PASSWORD --interactive=false $EXTRA_ARGS

# Docker publish to push image to Artifactory
run jfrog rt dp $DOCKER_IMAGE_TAG $DOCKER_TARGET_REPO --build-name=$BUILD_NAME --build-number=$BITBUCKET_BUILD_NUMBER $EXTRA_ARGS

# Capture environment variables for build information
if [[ "${COLLECT_ENV}" == "true" ]]; then
   info "Capturing environment variables"
   run jfrog rt bce $BUILD_NAME $BITBUCKET_BUILD_NUMBER $EXTRA_ARGS
fi

# Publish build information to Artifactory
if [[ "${COLLECT_BUILD_INFO}" == "true" ]]; then
   info "Capturing build information"
   run jfrog rt bp $BUILD_NAME $BITBUCKET_BUILD_NUMBER $EXTRA_ARGS
fi

if [[ "${status}" -eq 0 ]]; then
  success "Docker Image \"$DOCKER_IMAGE_TAG\" is published successfully to \"$DOCKER_TARGET_REPO\"."
else
  fail "Failed to publish Docker Image \"$DOCKER_IMAGE_TAG\"."
fi
